@@ -1,4 +1,4 @@
-# Copyright 2018 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 
 """asyncio bridge to the standard sqlite3 module"""
@@ -9,20 +9,23 @@ from sqlite3 import (  # pylint: disable=redefined-builtin
     IntegrityError,
     NotSupportedError,
     OperationalError,
+    paramstyle,
     ProgrammingError,
-    Row,
-    Warning,
     register_adapter,
     register_converter,
+    Row,
     sqlite_version,
     sqlite_version_info,
+    Warning,
 )
 
-from .core import Connection, Cursor, connect
+__author__ = "Amethyst Reese"
+from .__version__ import __version__
+from .core import connect, Connection, Cursor
 
-__version__ = "0.15.0"
 __all__ = [
     "__version__",
+    "paramstyle",
     "register_adapter",
     "register_converter",
     "sqlite_version",
