@@ -1,4 +1,4 @@
-# Copyright 2018 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 import asyncio
 import sqlite3
@@ -6,9 +6,12 @@ import sys
 from pathlib import Path
 from sqlite3 import OperationalError
 from threading import Thread
-from unittest import SkipTest, skipIf, skipUnless
+from unittest import skipIf, SkipTest, skipUnless
 
-import aiounittest
+if sys.version_info < (3, 8):
+    from aiounittest import AsyncTestCase as TestCase
+else:
+    from unittest import IsolatedAsyncioTestCase as TestCase
 
 import aiosqlite
 from .helpers import setup_logger
@@ -22,7 +25,7 @@ except ImportError:
     default_text_factory = str
 
 
-class SmokeTest(aiounittest.AsyncTestCase):
+class SmokeTest(TestCase):
     @classmethod
     def setUpClass(cls):
         setup_logger()
@@ -239,6 +242,17 @@ class SmokeTest(aiounittest.AsyncTestCase):
                 with self.assertRaises(TypeError):
                     _ = row["k"]
 
+            async with db.cursor() as cursor:
+                cursor.row_factory = aiosqlite.Row
+                self.assertEqual(cursor.row_factory, aiosqlite.Row)
+                await cursor.execute("select * from test_properties")
+                row = await cursor.fetchone()
+                self.assertIsInstance(row, aiosqlite.Row)
+                self.assertEqual(row[1], 1)
+                self.assertEqual(row[2], "hi")
+                self.assertEqual(row["k"], 1)
+                self.assertEqual(row["d"], "hi")
+
             db.row_factory = aiosqlite.Row
             db.text_factory = bytes
             self.assertEqual(db.row_factory, aiosqlite.Row)
@@ -276,14 +290,16 @@ class SmokeTest(aiounittest.AsyncTestCase):
                 await db.load_extension("test")
             except OperationalError as e:
                 assert "not authorized" not in e.args
-            except AttributeError:
+            except AttributeError as e:
                 raise SkipTest(
                     "python was not compiled with sqlite3 "
                     "extension support, so we can't test it"
-                )
+                ) from e
 
     async def test_set_progress_handler(self):
-        """Assert that after setting a progress handler returning 1, DB operations are aborted"""
+        """
+        Assert that after setting a progress handler returning 1, DB operations are aborted
+        """
         async with aiosqlite.connect(TEST_DB) as db:
             await db.set_progress_handler(lambda: 1, 1)
             with self.assertRaises(OperationalError):
@@ -439,7 +455,6 @@ class SmokeTest(aiounittest.AsyncTestCase):
                 rows = await cursor.fetchall()
                 self.assertEqual(rows, [(1, "hello"), (2, "world")])
 
-    @skipIf(sys.version_info < (3, 7), "Test backup() on 3.7+")
     async def test_backup_sqlite(self):
         async with aiosqlite.connect(":memory:") as db1:
             with sqlite3.connect(":memory:") as db2:
@@ -457,11 +472,3 @@ class SmokeTest(aiounittest.AsyncTestCase):
                 cursor = db2.execute("select * from foo")
                 rows = cursor.fetchall()
                 self.assertEqual(rows, [(1, "hello"), (2, "world")])
-
-    @skipUnless(sys.version_info < (3, 7), "Test short circuit fail on Py 3.6")
-    async def test_backup_py36(self):
-        async with aiosqlite.connect(":memory:") as db1, aiosqlite.connect(
-            ":memory:"
-        ) as db2:
-            with self.assertRaisesRegex(RuntimeError, "backup().+3.7"):
-                await db1.backup(db2)
